diff Framework/Deprecated/Toolbox/DicomFrameConverter.h @ 1298:8a0a62189f46

replacing std::auto_ptr by std::unique_ptr
author Sebastien Jodogne <s.jodogne@gmail.com>
date Mon, 02 Mar 2020 16:31:30 +0100
parents 2d8ab34c8c91
children 30deba7bc8e2
line wrap: on
line diff
--- a/Framework/Deprecated/Toolbox/DicomFrameConverter.h	Sun Feb 23 15:25:49 2020 +0100
+++ b/Framework/Deprecated/Toolbox/DicomFrameConverter.h	Mon Mar 02 16:31:30 2020 +0100
@@ -22,6 +22,7 @@
 #pragma once
 
 #include <Plugins/Samples/Common/IDicomDataset.h>
+#include <Core/Compatibility.h>
 #include <Core/DicomFormat/DicomMap.h>
 #include <Core/Images/ImageAccessor.h>
 
@@ -63,7 +64,7 @@
     {
       // TODO: check whether this dtor is called or not
       // An MSVC warning explains that declaring an
       // std::auto_ptr with a forward-declared type
       // prevents its dtor from being called. Does not
       // seem an issue here (only POD types inside), but
       // definitely something to keep an eye on.
@@ -157,7 +158,7 @@
       return rescaleSlope_;
     }
 
-    void ConvertFrameInplace(std::auto_ptr<Orthanc::ImageAccessor>& source) const;
+    void ConvertFrameInplace(std::unique_ptr<Orthanc::ImageAccessor>& source) const;
 
     Orthanc::ImageAccessor* ConvertFrame(const Orthanc::ImageAccessor& source) const;
@@ -63,7 +64,7 @@
       // TODO: check whether this dtor is called or not
       // An MSVC warning explains that declaring an
-      // std::auto_ptr with a forward-declared type
+      // std::unique_ptr with a forward-declared type
       // prevents its dtor from being called. Does not
       // seem an issue here (only POD types inside), but